find_percentage_genes: Calculates the fraction of counts from genes matching a...

Description Usage Arguments Value Examples

View source: R/find_percentage_genes.R

Description

Subsets gene names that match the pattern supplied. The percentage fraction of this gene group is then calculated.

Usage

1
find_percentage_genes(object = obj, pattern = '^MT-', assay = 'RAW', slot = 'RAW', column.name = 'RAW_percent.mt')

Arguments

object

IBRAP S4 class object

pattern

A character string containing a pattern to identfiy in rownames

assay

String indicating which assay to source the raw counts from

slot

String indicating which slot within the assay should be sourced

column.name

String naming the column name in the metadata

Value

IBRAP S4 class object containing highly varaible genes within the source assay

Examples

1
object <- find_percentage_genes(object = object, pattern = '^MT-',

connorhknight/IBRAP_no_decontX documentation built on Feb. 13, 2022, 2:32 p.m.